@@ -2,8 +2,6 @@ context("migpd")
 
 test_that("migpd behaves as it should", {
   skip_on_cran()
-  skip_on_travis()
-    
   # values from Heffernan and Tawn (2004) Table 4.
   # Note values in published Table 4 for u_{Xi} in cols NO2 and NO Winter were reversed.
   
@@ -22,15 +20,19 @@ test_that("migpd behaves as it should", {
   
   tol <- c(1, 0.05, .5, 0.5)
   for(i in 1:4){
-    expect_that(htsummer[i, ], equals(unname(summer.gpd[i,]), tolerance=tol[i]), label=paste("migpd:Table4summer", i))
-    expect_that(htwinter[i, ], equals(unname(winter.gpd[i,]), tolerance=tol[i]), label=paste("migpd:Table4winter", i))
+      expect_equal(htsummer[i, ], unname(summer.gpd[i,]),
+                   tolerance=tol[i], label=paste("migpd:Table4summer", i))
+      expect_equal(htwinter[i, ], unname(winter.gpd[i,]),
+                   tolerance=tol[i], label=paste("migpd:Table4winter", i))
   }
   
   # check excecution for 2-d data
   
   wavesurge.fit <- migpd(wavesurge,mqu=.7)
-  expect_that(wavesurge.fit$models$wave$loglik, equals(evm(wavesurge$wave, qu=0.7)$loglik, tolerance=0.001),
-              label="migpd: 2-d data gpd fit wave")
+  expect_equal(wavesurge.fit$models$wave$loglik,
+               evm(wavesurge$wave, qu=0.7)$loglik,
+               tolerance=0.001,
+               label="migpd: 2-d data gpd fit wave")
   
 }
 )
